@@ -102,7 +102,7 @@ public class RemoveFlagActionCommandParser implements CommandParser<ActionComman
      */
     @SuppressWarnings("unchecked")
     @Override
-    public void parse(JSONObject jsonObject, ActionCommand actionCommand) throws JSONException, OXException {
+    public void parse(JSONObject jsonObject, ActionCommand actionCommand) throws JSONException {
         ArrayList<Object> arguments = actionCommand.getArguments();
 
         jsonObject.put(GeneralField.id.name(), ActionCommand.Commands.REMOVEFLAG.getJsonName());
