@@ -182,7 +182,7 @@ public class SizeTestCommandParser implements CommandParser<TestCommand> {
         jsonObject.put(SizeTestField.comparison.name(), command.getMatchType().substring(1));
         Object value = command.getArguments().get(1);
         if (value instanceof NumberArgument) {
-            Integer intVal = ((NumberArgument) value).getInteger();
+            int intVal = ((NumberArgument) value).getInteger().intValue();
             int returnVal = 0;
             String type = null;
             if (intVal % 1073741824 == 0) {
