@@ -49,6 +49,8 @@
 
 package com.openexchange.jsieve.export;
 
+import static com.openexchange.java.Autoboxing.L;
+import static com.openexchange.java.Charsets.UTF_8;
 import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -62,6 +64,7 @@ import java.net.SocketTimeoutException;
 import java.net.UnknownHostException;
 import java.nio.charset.UnsupportedCharsetException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -99,7 +102,7 @@ public class SieveHandler {
     /**
      * The logger.
      */
-    private static org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(SieveHandler.class);
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(SieveHandler.class);
 
     /**
      * The constant for CRLF (carriage-return line-feed).
@@ -263,7 +266,7 @@ public class SieveHandler {
      */
     private void measureEnd(final String method) {
         long end = System.currentTimeMillis();
-        log.debug("SieveHandler.{}() took {}ms to perform", method, (end - this.mStart));
+        log.debug("SieveHandler.{}() took {}ms to perform", method, L(end - this.mStart));
     }
 
     /**
@@ -379,7 +382,7 @@ public class SieveHandler {
          * Set timeout to the one specified in the config file or the one which was explicitly set
          */
         s_sieve.setSoTimeout(getEffectiveReadTimeout(configuredTimeout));
-        bis_sieve = new BufferedReader(new InputStreamReader(s_sieve.getInputStream(), com.openexchange.java.Charsets.UTF_8));
+        bis_sieve = new BufferedReader(new InputStreamReader(s_sieve.getInputStream(), UTF_8));
         bos_sieve = new BufferedOutputStream(s_sieve.getOutputStream());
 
         if (!getServerWelcome()) {
@@ -422,7 +425,7 @@ public class SieveHandler {
                  * S: OK
                  */
                 measureStart();
-                bos_sieve.write(commandBuilder.append("STARTTLS").append(CRLF).toString().getBytes(com.openexchange.java.Charsets.UTF_8));
+                bos_sieve.write(commandBuilder.append("STARTTLS").append(CRLF).toString().getBytes(UTF_8));
                 bos_sieve.flush();
                 measureEnd("startTLS");
                 commandBuilder.setLength(0);
@@ -443,7 +446,7 @@ public class SieveHandler {
                  * Switch to TLS
                  */
                 s_sieve = SocketFetcher.startTLS(s_sieve, sieve_host);
-                bis_sieve = new BufferedReader(new InputStreamReader(s_sieve.getInputStream(), com.openexchange.java.Charsets.UTF_8));
+                bis_sieve = new BufferedReader(new InputStreamReader(s_sieve.getInputStream(), UTF_8));
                 bos_sieve = new BufferedOutputStream(s_sieve.getOutputStream());
                 /*
                  * Fire CAPABILITY command but only for cyrus that is not sieve draft conform to sent CAPABILITY response again
@@ -452,7 +455,7 @@ public class SieveHandler {
                 final String implementation = capa.getImplementation();
                 if (implementation.matches(mailFilterConfig.getProperty(userId, contextId, MailFilterProperty.nonRFCCompliantTLSRegex))) {
                     measureStart();
-                    bos_sieve.write(commandBuilder.append("CAPABILITY").append(CRLF).toString().getBytes(com.openexchange.java.Charsets.UTF_8));
+                    bos_sieve.write(commandBuilder.append("CAPABILITY").append(CRLF).toString().getBytes(UTF_8));
                     bos_sieve.flush();
                     measureEnd("capability");
                     commandBuilder.setLength(0);
@@ -509,7 +512,7 @@ public class SieveHandler {
         }
 
         final String capability = SIEVE_CAPABILITY;
-        bos_sieve.write(capability.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(capability.getBytes(UTF_8));
         bos_sieve.flush();
 
         // Forget previous capabilities
@@ -547,7 +550,7 @@ public class SieveHandler {
                 try {
                     configuredPreferredSASLMechanism = PreferredSASLMech.valueOf(psm);
                 } catch (IllegalArgumentException e) {
-                    log.warn("Invalid property '{}' for '{}' found in mailfilter.properties.", psm, MailFilterProperty.preferredSaslMech.getFQPropertyName());
+                    log.warn("Invalid property '{}' for '{}' found in mailfilter.properties.", psm, MailFilterProperty.preferredSaslMech.getFQPropertyName(), e);
                 }
             }
             if (null == configuredPreferredSASLMechanism) {
@@ -595,10 +598,10 @@ public class SieveHandler {
         String put = commandBuilder.append(SIEVE_PUT).append('\"').append(script_name).append("\" {").append(script.length).append("+}").append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(put.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(put.getBytes(UTF_8));
         bos_sieve.write(script);
 
-        bos_sieve.write(CRLF.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(CRLF.getBytes(UTF_8));
         bos_sieve.flush();
 
         String currentLine = bis_sieve.readLine();
@@ -645,7 +648,7 @@ public class SieveHandler {
         }
         final StringBuilder sb = new StringBuilder(32);
         final String get = sb.append(SIEVE_GET_SCRIPT).append('"').append(script_name).append('"').append(CRLF).toString();
-        bos_sieve.write(get.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(get.getBytes(UTF_8));
         bos_sieve.flush();
         sb.setLength(0);
         /*-
@@ -858,7 +861,7 @@ public class SieveHandler {
         }
 
         final String active = SIEVE_LIST;
-        bos_sieve.write(active.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(active.getBytes(UTF_8));
         bos_sieve.flush();
 
         final ArrayList<String> list = new ArrayList<String>();
@@ -882,25 +885,38 @@ public class SieveHandler {
     }
 
     /**
-     * Get the list of active sieve scripts
+     * Gets the name of the currently active sieve script.
      *
-     * @return List of scripts, or null if no script is active
+     * @return The name of the active script, or <code>null</code> if no script is active
      * @throws IOException
      * @throws UnsupportedEncodingException
      * @throws OXSieveHandlerException
      */
     public String getActiveScript() throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
+        return getActiveScript(null);
+    }
+
+    /**
+     * Gets the name of the currently active sieve script.
+     *
+     * @param optExpectedName The optional expected name or <code>null</code>
+     * @return The name of the active script, or <code>null</code> if no script is active
+     * @throws IOException
+     * @throws UnsupportedEncodingException
+     * @throws OXSieveHandlerException
+     */
+    public String getActiveScript(String optExpectedName) throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
         if (!(AUTH)) {
             throw new OXSieveHandlerException("List scripts not possible. Auth first.", sieve_host, sieve_host_port, null);
         }
 
         final String active = SIEVE_LIST;
-        bos_sieve.write(active.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(active.getBytes(UTF_8));
         bos_sieve.flush();
 
         String scriptname = null;
         while (true) {
-            final String temp = bis_sieve.readLine();
+            String temp = bis_sieve.readLine();
             if (null == temp) {
                 throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, null);
             }
@@ -911,11 +927,96 @@ public class SieveHandler {
                 throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
 
-            if (temp.matches(".*ACTIVE")) {
-                scriptname = temp.substring(temp.indexOf('\"') + 1, temp.lastIndexOf('\"'));
+            int count = -1;
+            if (temp.startsWith("{")) {
+                count = Integer.parseInt(temp.substring(1, temp.lastIndexOf('}')));
+                temp = bis_sieve.readLine();
+                if (null == temp) {
+                    throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, null);
+                }
+            }
+
+            if (temp.endsWith(" ACTIVE")) {
+                if (count >= 0) {
+                    // Literal
+                    scriptname = temp.substring(0, count);
+                } else if (temp.startsWith("\"")) {
+                    // QuotedString
+                    scriptname = temp.substring(1, temp.lastIndexOf('\"'));
+                } else {
+                    // Atom
+                    scriptname = readAtom(temp);
+                }
+                if (optExpectedName != null && !scriptname.equals(optExpectedName)) {
+                    throw new OXSieveHandlerException("Currently active script \"" + scriptname + "\" is not the expected one \"" + optExpectedName + '\"', sieve_host, sieve_host_port, null);
+                }
             }
         }
+    }
 
+    /**
+     * Lists the scripts the user has on the server.
+     *
+     * @return The listed scripts
+     * @throws OXSieveHandlerException
+     * @throws UnsupportedEncodingException
+     * @throws IOException
+     */
+    public List<SieveScript> listScripts() throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
+        if (!(AUTH)) {
+            throw new OXSieveHandlerException("List scripts not possible. Auth first.", sieve_host, sieve_host_port, null);
+        }
+
+        bos_sieve.write(SIEVE_LIST.getBytes(UTF_8));
+        bos_sieve.flush();
+
+        List<SieveScript> scrips = null;
+        while (true) {
+            String temp = bis_sieve.readLine();
+            if (null == temp) {
+                throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, null);
+            }
+            if (temp.startsWith(SIEVE_OK)) {
+                return scrips == null ? Collections.emptyList() : scrips;
+            }
+            if (temp.startsWith(SIEVE_NO)) {
+                throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
+            }
+
+            String scriptName;
+            if (temp.startsWith("\"")) {
+                // QuotedString
+                scriptName = temp.substring(1, temp.lastIndexOf('\"'));
+            } else if (temp.startsWith("{")) {
+                // Literal
+                int count = Integer.parseInt(temp.substring(1, temp.lastIndexOf('}')));
+                temp = bis_sieve.readLine();
+                if (null == temp) {
+                    throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, null);
+                }
+                scriptName = temp.substring(0, count);
+            } else {
+                // Atom
+                scriptName = readAtom(temp);
+            }
+
+            boolean active = temp.endsWith(" ACTIVE");
+            if (scrips == null) {
+                scrips = new ArrayList<SieveScript>(4);
+            }
+            scrips.add(new SieveScript(scriptName, active));
+        }
+    }
+
+    private static String ASTRING_CHAR_DELIM = " (){%*\"\\";
+
+    private static String readAtom(String line) {
+        int end = 0;
+        char c;
+        while (end < line.length() && (c = line.charAt(end)) >= ' ' && ASTRING_CHAR_DELIM.indexOf(c) < 0 && c != 0x7F) {
+            end++;
+        }
+        return line.substring(0, end);
     }
 
     /**
@@ -941,7 +1042,7 @@ public class SieveHandler {
         final String delete = commandBuilder.append(SIEVE_DELETE).append('"').append(script_name).append('"').append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(delete.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(delete.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -965,7 +1066,7 @@ public class SieveHandler {
      */
     public void close() throws IOException, UnsupportedEncodingException {
         if (null != bos_sieve) {
-            bos_sieve.write(SIEVE_LOGOUT.getBytes(com.openexchange.java.Charsets.UTF_8));
+            bos_sieve.write(SIEVE_LOGOUT.getBytes(UTF_8));
             bos_sieve.flush();
         }
         if (null != s_sieve) {
@@ -992,7 +1093,7 @@ public class SieveHandler {
         }
     }
 
-    private boolean authXOAUTH2(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException, OXSieveHandlerException {
+    private boolean authXOAUTH2(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException {
         if (Strings.isEmpty(oauthToken)) {
             return false;
         }
@@ -1003,11 +1104,11 @@ public class SieveHandler {
         {
             String auth_mech_string = commandBuilder.append(SIEVE_AUTH).append("\"XOAUTH2\" {").append(irs.length()).append("+}").append(CRLF).toString();
             commandBuilder.setLength(0);
-            bos_sieve.write(auth_mech_string.getBytes());
+            bos_sieve.write(auth_mech_string.getBytes(UTF_8));
         }
 
-        bos_sieve.write(irs.getBytes());
-        bos_sieve.write(CRLF.getBytes());
+        bos_sieve.write(irs.getBytes(UTF_8));
+        bos_sieve.write(CRLF.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1027,7 +1128,7 @@ public class SieveHandler {
         }
     }
 
-    private boolean authOAUTHBEARER(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException, OXSieveHandlerException {
+    private boolean authOAUTHBEARER(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException {
         if (Strings.isEmpty(oauthToken)) {
             return false;
         }
@@ -1062,7 +1163,7 @@ public class SieveHandler {
         }
     }
 
-    private boolean authGSSAPI(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException, OXSieveHandlerException {
+    private boolean authGSSAPI() throws IOException, UnsupportedEncodingException, OXSieveHandlerException {
         final String authname = getRightEncodedString(sieve_auth, "authname");
 
         final HashMap<String, String> saslProps = new HashMap<String, String>();
@@ -1086,11 +1187,11 @@ public class SieveHandler {
             byte[] response = sc.evaluateChallenge(new byte[0]);
             String b64resp = com.openexchange.tools.encoding.Base64.encode(response);
 
-            bos_sieve.write(new String(SIEVE_AUTH + "\"GSSAPI\" {" + b64resp.length() + "+}").getBytes());
-            bos_sieve.write(CRLF.getBytes());
+            bos_sieve.write(new String(SIEVE_AUTH + "\"GSSAPI\" {" + b64resp.length() + "+}").getBytes(UTF_8));
+            bos_sieve.write(CRLF.getBytes(UTF_8));
             bos_sieve.flush();
-            bos_sieve.write(b64resp.getBytes());
-            bos_sieve.write(CRLF.getBytes());
+            bos_sieve.write(b64resp.getBytes(UTF_8));
+            bos_sieve.write(CRLF.getBytes(UTF_8));
             bos_sieve.flush();
 
             while (true) {
@@ -1131,11 +1232,11 @@ public class SieveHandler {
                             b64resp = com.openexchange.tools.encoding.Base64.encode(response);
                             respLiteral = "{" + b64resp.length() + "+}";
                         }
-                        bos_sieve.write(new String(respLiteral + CRLF).getBytes());
+                        bos_sieve.write(new String(respLiteral + CRLF).getBytes(UTF_8));
                         if (null != response && response.length > 0) {
-                            bos_sieve.write(new String(b64resp + CRLF).getBytes());
+                            bos_sieve.write(new String(b64resp + CRLF).getBytes(UTF_8));
                         } else {
-                            bos_sieve.write(CRLF.getBytes());
+                            bos_sieve.write(CRLF.getBytes(UTF_8));
                         }
                         bos_sieve.flush();
                     }
@@ -1170,9 +1271,9 @@ public class SieveHandler {
         commandBuilder.setLength(0);
 
         // We don't need to specify an encoding here because all strings contain only ASCII Text
-        bos_sieve.write(auth_mech_string.getBytes());
-        bos_sieve.write(user_size.getBytes());
-        bos_sieve.write(user_auth_pass_64.getBytes());
+        bos_sieve.write(auth_mech_string.getBytes(UTF_8));
+        bos_sieve.write(user_size.getBytes(UTF_8));
+        bos_sieve.write(user_auth_pass_64.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1198,7 +1299,7 @@ public class SieveHandler {
         final String auth_mech_string = commandBuilder.append(SIEVE_AUTH).append("\"LOGIN\"").append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(auth_mech_string.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(auth_mech_string.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1219,8 +1320,8 @@ public class SieveHandler {
         final String user_size = commandBuilder.append('{').append((user64.length() - 2)).append("+}").append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(user_size.getBytes(com.openexchange.java.Charsets.UTF_8));
-        bos_sieve.write(user64.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(user_size.getBytes(UTF_8));
+        bos_sieve.write(user64.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1241,8 +1342,8 @@ public class SieveHandler {
         final String pass_size = commandBuilder.append('{').append((pass64.length() - 2)).append("+}").append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(pass_size.getBytes(com.openexchange.java.Charsets.UTF_8));
-        bos_sieve.write(pass64.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(pass_size.getBytes(UTF_8));
+        bos_sieve.write(pass64.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1259,16 +1360,6 @@ public class SieveHandler {
         }
     }
 
-    /**
-     * Old method for compatibility reasons
-     *
-     * @deprecated use {@link #parseSIEVEResponse(String, String)} instead
-     */
-    @Deprecated
-    protected SieveResponse.Code parseSIEVEResponse(final String resp) {
-        return parseSIEVEResponse(resp, null);
-    }
-
     /**
      * Parse the https://tools.ietf.org/html/rfc5804#section-1.3 Response code of a SIEVE
      * response line.
@@ -1277,7 +1368,7 @@ public class SieveHandler {
      * @param response line
      * @return null, if no response code in line, the @{SIEVEResponse.Code} otherwise.
      */
-    protected SieveResponse.Code parseSIEVEResponse(final String resp, final String multiline) {
+    protected SieveResponse parseSIEVEResponse(final String resp, final String multiline) {
         if (!useSIEVEResponseCodes || null == resp) {
             return null;
         }
@@ -1287,16 +1378,14 @@ public class SieveHandler {
         if (m.matches()) {
             final int gcount = m.groupCount();
             if (gcount > 1) {
-                final SieveResponse.Code ret = SieveResponse.Code.getCode(m.group(1));
+                final SieveResponse.Code code = SieveResponse.Code.getCode(m.group(1));
                 final String group = m.group(2);
                 if (group.startsWith("{")) {
                     // Multi line, use the multiline parsed before here
-                    ret.setMessage(multiline);
-                } else {
-                    // Single line
-                    ret.setMessage(group);
+                    return new SieveResponse(code, multiline);
                 }
-                return ret;
+                // Single line
+                return new SieveResponse(code, group);
             }
         }
         return null;
@@ -1310,7 +1399,7 @@ public class SieveHandler {
         final String active = commandBuilder.append(SIEVE_ACTIVE).append('\"').append(sieve_script_name).append('\"').append(CRLF).toString();
         commandBuilder.setLength(0);
 
-        bos_sieve.write(active.getBytes(com.openexchange.java.Charsets.UTF_8));
+        bos_sieve.write(active.getBytes(UTF_8));
         bos_sieve.flush();
 
         while (true) {
@@ -1337,7 +1426,7 @@ public class SieveHandler {
         }
 
         if (scriptactive) {
-            bos_sieve.write(SIEVE_DEACTIVE.getBytes(com.openexchange.java.Charsets.UTF_8));
+            bos_sieve.write(SIEVE_DEACTIVE.getBytes(UTF_8));
             bos_sieve.flush();
 
             while (true) {
@@ -1392,7 +1481,7 @@ public class SieveHandler {
             try {
                 switch (auth_mech) {
                     case GSSAPI:
-                        return authGSSAPI(commandBuilder);
+                        return authGSSAPI();
                     case LOGIN:
                         return authLOGIN(commandBuilder);
                     case OAUTHBEARER:
@@ -1438,7 +1527,7 @@ public class SieveHandler {
         try {
             keyword = WelcomeKeyword.valueOf(token);
         } catch (IllegalArgumentException e) {
-            log.debug("Unknown keyword '{}'", token);
+            log.debug("Unknown keyword '{}'", token, e);
             return;
         }
 
@@ -1461,7 +1550,7 @@ public class SieveHandler {
                 try {
                     capa.addExtendedProperty(keyword.name(), Integer.valueOf(unquoted));
                 } catch (NumberFormatException ex) {
-                    log.error("Unable to parse '{}' capability value: {}", keyword, unquoted);
+                    log.error("Unable to parse '{}' capability value: {}", keyword, unquoted, ex);
                 }
                 return;
             case SASL: {
@@ -1492,9 +1581,8 @@ public class SieveHandler {
      * @param actualline
      * @return
      * @throws IOException
-     * @throws OXSieveHandlerException
      */
-    private String parseError(final String actualline) throws IOException, OXSieveHandlerException {
+    private String parseError(final String actualline) throws IOException {
         final StringBuilder sb = new StringBuilder();
         final String answer = actualline.substring(3);
         final Matcher matcher = LITERAL_S2C_PATTERN.matcher(answer);
@@ -1509,12 +1597,11 @@ public class SieveHandler {
                 sb.append(buf, 0, octetsRead);
             }
             return sb.toString();
-        } else {
-            return parseQuotedErrorMessage(answer);
         }
+        return parseQuotedErrorMessage(answer);
     }
 
-    private String parseQuotedErrorMessage(final String answer) throws IOException, OXSieveHandlerException {
+    private String parseQuotedErrorMessage(final String answer) throws IOException {
         StringBuilder inputBuilder = new StringBuilder();
         String line = answer;
         while (line != null) {
