@@ -49,6 +49,7 @@
 
 package com.openexchange.mailfilter.internal;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.security.PrivilegedActionException;
@@ -244,7 +245,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (IOException e) {
-                throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
+                throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), I(sieveHandler.getSievePort()));
             }
         }
     }
@@ -255,10 +256,11 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
      * <b>Must only be called when holding lock!</b>
      *
      * @param sieveHandler The Sieve handler to use
+     * @param expectedScriptName The expected name for the active script or <code>null</code>
      * @return The action Siege script or an empty string
      */
-    private String getScript(SieveHandler sieveHandler) throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
-        String activeScript = sieveHandler.getActiveScript();
+    private String getScript(SieveHandler sieveHandler, String expectedScriptName) throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
+        String activeScript = sieveHandler.getActiveScript(expectedScriptName);
         return null != activeScript ? sieveHandler.getScript(activeScript) : "";
     }
 
@@ -271,7 +273,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
 
-                String activeScript = sieveHandler.getActiveScript();
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
                 String script = (activeScript != null) ? sieveHandler.getScript(activeScript) : "";
 
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
@@ -297,7 +300,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
-                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
+                writeScript(sieveHandler, activeScript, writeback, expectedScriptName);
 
                 return nextuid;
             } catch (UnsupportedEncodingException e) {
@@ -325,7 +328,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
 
-                String activeScript = sieveHandler.getActiveScript();
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
                 if (null == activeScript) {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
@@ -337,7 +341,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 ClientRulesAndRequire clientRulesAndReq = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
                 RuleAndPosition rightRule = getRightRuleForUniqueId(clientRulesAndReq.getRules(), uid);
                 if (rightRule == null) {
-                    throw MailFilterExceptionCode.NO_SUCH_ID.create(uid, credentials.getUserid(), credentials.getContextid());
+                    throw MailFilterExceptionCode.NO_SUCH_ID.create(I(uid), I(credentials.getUserid()), I(credentials.getContextid()));
                 }
 
                 // Check redirect limit
@@ -354,7 +358,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
 
-                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
+                writeScript(sieveHandler, activeScript, writeback, expectedScriptName);
             } catch (ParseException e) {
                 throw MailFilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (SieveException e) {
@@ -383,7 +387,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
 
-                String activeScript = sieveHandler.getActiveScript();
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
                 if (null == activeScript) {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
@@ -396,13 +401,13 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 for (int uid : uids) {
                     RuleAndPosition deletedrule = getRightRuleForUniqueId(rules, uid);
                     if (deletedrule == null) {
-                        throw MailFilterExceptionCode.NO_SUCH_ID.create(uid, credentials.getUserid(), credentials.getContextid());
+                        throw MailFilterExceptionCode.NO_SUCH_ID.create(I(uid), I(credentials.getUserid()), I(credentials.getContextid()));
                     }
                     rules.remove(deletedrule.rule);
                 }
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
-                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
+                writeScript(sieveHandler, activeScript, writeback, expectedScriptName);
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
@@ -426,10 +431,12 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String activeScript = sieveHandler.getActiveScript();
+
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 String writeback = sieveTextFilter.writeEmptyScript();
-                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
+                writeScript(sieveHandler, activeScript, writeback, expectedScriptName);
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
@@ -449,7 +456,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                return getScript(sieveHandler);
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                return getScript(sieveHandler, expectedScriptName);
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (IOException e) {
@@ -478,7 +486,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String script = getScript(sieveHandler);
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String script = getScript(sieveHandler, expectedScriptName);
                 LOGGER.debug("The following sieve script will be parsed:\n{}", script);
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
@@ -534,7 +543,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String script = getScript(sieveHandler);
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String script = getScript(sieveHandler, expectedScriptName);
                 LOGGER.debug("The following sieve script will be parsed:\n{}", script);
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
@@ -573,34 +583,33 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String activeScript = sieveHandler.getActiveScript();
-                if (null != activeScript) {
-                    String script = sieveHandler.getScript(activeScript);
-                    RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
-
-                    ClientRulesAndRequire clientrulesandrequire = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
-
-                    List<Rule> clientrules = clientrulesandrequire.getRules();
-
-                    if (uids.length > clientrules.size()) {
-                        LOGGER.debug("The contents of the reorder array are: {}", uids);
-                        throw MailFilterExceptionCode.INVALID_REORDER_ARRAY.create(uids.length, clientrules.size(), credentials.getUserid(), credentials.getContextid());
-                    }
-
-                    // Identify rule groups
-                    List<MailFilterGroup> groups = getMailFilterGroups(uids);
-                    List<Rule> tmpList = new ArrayList<>(clientrules);
-                    clientrules.clear();
-                    for (MailFilterGroup group : groups) {
-                        clientrules.addAll(group.getOrderedRules(tmpList));
-                    }
-
-                    String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
-                    writeback = sieveTextFilter.rewriteRequire(writeback, script);
-                    writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
-                } else {
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
+                if (null == activeScript) {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
+
+                String script = sieveHandler.getScript(activeScript);
+                RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+
+                ClientRulesAndRequire clientrulesandrequire = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
+                List<Rule> clientrules = clientrulesandrequire.getRules();
+                if (uids.length > clientrules.size()) {
+                    LOGGER.debug("The contents of the reorder array are: {}", uids);
+                    throw MailFilterExceptionCode.INVALID_REORDER_ARRAY.create(I(uids.length), I(clientrules.size()), I(credentials.getUserid()), I(credentials.getContextid()));
+                }
+
+                // Identify rule groups
+                List<MailFilterGroup> groups = getMailFilterGroups(uids);
+                List<Rule> tmpList = new ArrayList<>(clientrules);
+                clientrules.clear();
+                for (MailFilterGroup group : groups) {
+                    clientrules.addAll(group.getOrderedRules(tmpList));
+                }
+
+                String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                writeback = sieveTextFilter.rewriteRequire(writeback, script);
+                writeScript(sieveHandler, activeScript, writeback, expectedScriptName);
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (ParseException e) {
@@ -635,7 +644,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
 
-                String activeScript = sieveHandler.getActiveScript();
+                String expectedScriptName = getScriptName(credentials.getUserid(), credentials.getContextid());
+                String activeScript = sieveHandler.getActiveScript(expectedScriptName);
                 if (activeScript == null) {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
@@ -769,7 +779,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
      * @param contextId
      * @return
      */
-    private boolean useSIEVEResponseCodes(int userId, int contextId) {
+    boolean useSIEVEResponseCodes(int userId, int contextId) {
         LeanConfigurationService config = services.getService(LeanConfigurationService.class);
         return config.getBooleanProperty(userId, contextId, MailFilterProperty.useSIEVEResponseCodes);
     }
@@ -858,7 +868,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             return;
         }
         Integer maxRedirects = (Integer) maxRedirectObject;
-        if (size > maxRedirects) {
+        if (size > maxRedirects.intValue()) {
             throw MailFilterExceptionCode.TOO_MANY_REDIRECT.create();
         }
     }
@@ -1006,7 +1016,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
      * @param sieveHandler the sieveHandler to use
      * @param activeScript the activeScript
      * @param writeback the write-back String
-     * @param scriptName TODO
+     * @param scriptName The configured name of the script
      * @throws OXSieveHandlerException
      * @throws IOException
      * @throws UnsupportedEncodingException
@@ -1037,7 +1047,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
     /**
      * Search within the given List of Rules for the one matching the specified UID
      */
-    private RuleAndPosition getRightRuleForUniqueId(List<Rule> clientrules, int uniqueid) throws OXException {
+    private RuleAndPosition getRightRuleForUniqueId(List<Rule> clientrules, int uniqueid) {
         for (int i = 0; i < clientrules.size(); i++) {
             Rule rule = clientrules.get(i);
             if (uniqueid == rule.getUniqueId()) {
@@ -1059,7 +1069,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
      * Furthermore this method contains a thread synchronization if Kerberos is used. If the Kerberos subject is not <code>null</code>, that Kerberos subject object is used to only allow a single IMAP/SIEVE login per Kerberos
      * subject. The service ticket for the IMAP/SIEVE server is stored in the Kerberos subject once the IMAP/SIEVE login was successful. If multiple threads can execute this in concurrently, multiple service tickets are
      * requested, which is discouraged for performance reasons.
-     * 
+     *
      * @param sieveHandler The SIEVE handler to connect
      * @param kerberosSubject The optional Kerberos subject or <code>null</code>
      * @throws OXException
@@ -1072,7 +1082,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             if (kerberosSubject != null) {
                 synchronized (kerberosSubject) {
                     Subject.doAs(kerberosSubject, new PrivilegedExceptionAction<Object>() {
-    
+
                         @Override
                         public Object run() throws Exception {
                             sieveHandler.initializeConnection();
